
# This is a fix for InnoDB in MySQL >= 4.1.x
# It "suspends judgement" for fkey relationships until are tables are set.
SET FOREIGN_KEY_CHECKS = 0;

#-----------------------------------------------------------------------------
#-- group
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `group`;


CREATE TABLE `group`
(
	`id` INTEGER(11)  NOT NULL,
	`name` VARCHAR(45),
	`gid` INTEGER(11),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- group_machine
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `group_machine`;


CREATE TABLE `group_machine`
(
	`group_id` INTEGER(11)  NOT NULL,
	`machine_id` INTEGER(11)  NOT NULL,
	PRIMARY KEY (`group_id`,`machine_id`),
	KEY `fk_group_has_machine_machine1`(`machine_id`),
	CONSTRAINT `group_machine_FK_1`
		FOREIGN KEY (`group_id`)
		REFERENCES `group` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `group_machine_FK_2`
		FOREIGN KEY (`machine_id`)
		REFERENCES `machine` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- machine
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `machine`;


CREATE TABLE `machine`
(
	`id` INTEGER(11)  NOT NULL,
	`name` VARCHAR(45),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- user
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `user`;


CREATE TABLE `user`
(
	`id` INTEGER(11)  NOT NULL,
	`name` VARCHAR(45),
	`uid` INTEGER(11),
	`homedir` VARCHAR(255),
	`shell` VARCHAR(255),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- user_group
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `user_group`;


CREATE TABLE `user_group`
(
	`user_id` INTEGER(11)  NOT NULL,
	`group_id` INTEGER(11)  NOT NULL,
	PRIMARY KEY (`user_id`,`group_id`),
	KEY `fk_user_has_group_group1`(`group_id`),
	CONSTRAINT `user_group_FK_1`
		FOREIGN KEY (`user_id`)
		REFERENCES `user` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `user_group_FK_2`
		FOREIGN KEY (`group_id`)
		REFERENCES `group` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- user_machine
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `user_machine`;


CREATE TABLE `user_machine`
(
	`user_id` INTEGER(11)  NOT NULL,
	`machine_id` INTEGER(11)  NOT NULL,
	PRIMARY KEY (`user_id`,`machine_id`),
	KEY `fk_user_has_machine_machine1`(`machine_id`),
	CONSTRAINT `user_machine_FK_1`
		FOREIGN KEY (`user_id`)
		REFERENCES `user` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `user_machine_FK_2`
		FOREIGN KEY (`machine_id`)
		REFERENCES `machine` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

# This restores the fkey checks, after having unset them earlier
SET FOREIGN_KEY_CHECKS = 1;
