<?php

/**
 * Machine form base class.
 *
 * @method Machine getObject() Returns the current form's model object
 *
 * @package    sf_sandbox
 * @subpackage form
 * @author     Your name here
 */
abstract class BaseMachineForm extends BaseFormPropel
{
  public function setup()
  {
    $this->setWidgets(array(
      'id'                 => new sfWidgetFormInputHidden(),
      'name'               => new sfWidgetFormInputText(),
      'group_machine_list' => new sfWidgetFormPropelChoice(array('multiple' => true, 'model' => 'UnixGroup')),
      'user_machine_list'  => new sfWidgetFormPropelChoice(array('multiple' => true, 'model' => 'UnixUser')),
    ));

    $this->setValidators(array(
      'id'                 => new sfValidatorChoice(array('choices' => array($this->getObject()->getId()), 'empty_value' => $this->getObject()->getId(), 'required' => false)),
      'name'               => new sfValidatorString(array('max_length' => 45, 'required' => false)),
      'group_machine_list' => new sfValidatorPropelChoice(array('multiple' => true, 'model' => 'UnixGroup', 'required' => false)),
      'user_machine_list'  => new sfValidatorPropelChoice(array('multiple' => true, 'model' => 'UnixUser', 'required' => false)),
    ));

    $this->widgetSchema->setNameFormat('machine[%s]');

    $this->errorSchema = new sfValidatorErrorSchema($this->validatorSchema);

    parent::setup();
  }

  public function getModelName()
  {
    return 'Machine';
  }


  public function updateDefaultsFromObject()
  {
    parent::updateDefaultsFromObject();

    if (isset($this->widgetSchema['group_machine_list']))
    {
      $values = array();
      foreach ($this->object->getGroupMachines() as $obj)
      {
        $values[] = $obj->getUnixGroupId();
      }

      $this->setDefault('group_machine_list', $values);
    }

    if (isset($this->widgetSchema['user_machine_list']))
    {
      $values = array();
      foreach ($this->object->getUserMachines() as $obj)
      {
        $values[] = $obj->getUnixUserId();
      }

      $this->setDefault('user_machine_list', $values);
    }

  }

  protected function doSave($con = null)
  {
    parent::doSave($con);

    $this->saveGroupMachineList($con);
    $this->saveUserMachineList($con);
  }

  public function saveGroupMachineList($con = null)
  {
    if (!$this->isValid())
    {
      throw $this->getErrorSchema();
    }

    if (!isset($this->widgetSchema['group_machine_list']))
    {
      // somebody has unset this widget
      return;
    }

    if (null === $con)
    {
      $con = $this->getConnection();
    }

    $c = new Criteria();
    $c->add(GroupMachinePeer::MACHINE_ID, $this->object->getPrimaryKey());
    GroupMachinePeer::doDelete($c, $con);

    $values = $this->getValue('group_machine_list');
    if (is_array($values))
    {
      foreach ($values as $value)
      {
        $obj = new GroupMachine();
        $obj->setMachineId($this->object->getPrimaryKey());
        $obj->setUnixGroupId($value);
        $obj->save();
      }
    }
  }

  public function saveUserMachineList($con = null)
  {
    if (!$this->isValid())
    {
      throw $this->getErrorSchema();
    }

    if (!isset($this->widgetSchema['user_machine_list']))
    {
      // somebody has unset this widget
      return;
    }

    if (null === $con)
    {
      $con = $this->getConnection();
    }

    $c = new Criteria();
    $c->add(UserMachinePeer::MACHINE_ID, $this->object->getPrimaryKey());
    UserMachinePeer::doDelete($c, $con);

    $values = $this->getValue('user_machine_list');
    if (is_array($values))
    {
      foreach ($values as $value)
      {
        $obj = new UserMachine();
        $obj->setMachineId($this->object->getPrimaryKey());
        $obj->setUnixUserId($value);
        $obj->save();
      }
    }
  }

}
