<?php

/**
 * UnixGroup form base class.
 *
 * @method UnixGroup getObject() Returns the current form's model object
 *
 * @package    sf_sandbox
 * @subpackage form
 * @author     Your name here
 */
abstract class BaseUnixGroupForm extends BaseFormPropel
{
  public function setup()
  {
    $this->setWidgets(array(
      'id'                 => new sfWidgetFormInputHidden(),
      'name'               => new sfWidgetFormInputText(),
      'gid'                => new sfWidgetFormInputText(),
      'group_machine_list' => new sfWidgetFormPropelChoice(array('multiple' => true, 'model' => 'Machine')),
      'user_group_list'    => new sfWidgetFormPropelChoice(array('multiple' => true, 'model' => 'UnixUser')),
    ));

    $this->setValidators(array(
      'id'                 => new sfValidatorChoice(array('choices' => array($this->getObject()->getId()), 'empty_value' => $this->getObject()->getId(), 'required' => false)),
      'name'               => new sfValidatorString(array('max_length' => 45, 'required' => false)),
      'gid'                => new sfValidatorInteger(array('min' => -2147483648, 'max' => 2147483647, 'required' => false)),
      'group_machine_list' => new sfValidatorPropelChoice(array('multiple' => true, 'model' => 'Machine', 'required' => false)),
      'user_group_list'    => new sfValidatorPropelChoice(array('multiple' => true, 'model' => 'UnixUser', 'required' => false)),
    ));

    $this->widgetSchema->setNameFormat('unix_group[%s]');

    $this->errorSchema = new sfValidatorErrorSchema($this->validatorSchema);

    parent::setup();
  }

  public function getModelName()
  {
    return 'UnixGroup';
  }


  public function updateDefaultsFromObject()
  {
    parent::updateDefaultsFromObject();

    if (isset($this->widgetSchema['group_machine_list']))
    {
      $values = array();
      foreach ($this->object->getGroupMachines() as $obj)
      {
        $values[] = $obj->getMachineId();
      }

      $this->setDefault('group_machine_list', $values);
    }

    if (isset($this->widgetSchema['user_group_list']))
    {
      $values = array();
      foreach ($this->object->getUserGroups() as $obj)
      {
        $values[] = $obj->getUnixUserId();
      }

      $this->setDefault('user_group_list', $values);
    }

  }

  protected function doSave($con = null)
  {
    parent::doSave($con);

    $this->saveGroupMachineList($con);
    $this->saveUserGroupList($con);
  }

  public function saveGroupMachineList($con = null)
  {
    if (!$this->isValid())
    {
      throw $this->getErrorSchema();
    }

    if (!isset($this->widgetSchema['group_machine_list']))
    {
      // somebody has unset this widget
      return;
    }

    if (null === $con)
    {
      $con = $this->getConnection();
    }

    $c = new Criteria();
    $c->add(GroupMachinePeer::UNIX_GROUP_ID, $this->object->getPrimaryKey());
    GroupMachinePeer::doDelete($c, $con);

    $values = $this->getValue('group_machine_list');
    if (is_array($values))
    {
      foreach ($values as $value)
      {
        $obj = new GroupMachine();
        $obj->setUnixGroupId($this->object->getPrimaryKey());
        $obj->setMachineId($value);
        $obj->save();
      }
    }
  }

  public function saveUserGroupList($con = null)
  {
    if (!$this->isValid())
    {
      throw $this->getErrorSchema();
    }

    if (!isset($this->widgetSchema['user_group_list']))
    {
      // somebody has unset this widget
      return;
    }

    if (null === $con)
    {
      $con = $this->getConnection();
    }

    $c = new Criteria();
    $c->add(UserGroupPeer::UNIX_GROUP_ID, $this->object->getPrimaryKey());
    UserGroupPeer::doDelete($c, $con);

    $values = $this->getValue('user_group_list');
    if (is_array($values))
    {
      foreach ($values as $value)
      {
        $obj = new UserGroup();
        $obj->setUnixGroupId($this->object->getPrimaryKey());
        $obj->setUnixUserId($value);
        $obj->save();
      }
    }
  }

}
