<?php

/**
 * UnixUser form base class.
 *
 * @method UnixUser getObject() Returns the current form's model object
 *
 * @package    sf_sandbox
 * @subpackage form
 * @author     Your name here
 */
abstract class BaseUnixUserForm extends BaseFormPropel
{
  public function setup()
  {
    $this->setWidgets(array(
      'id'                => new sfWidgetFormInputHidden(),
      'name'              => new sfWidgetFormInputText(),
      'uid'               => new sfWidgetFormInputText(),
      'homedir'           => new sfWidgetFormInputText(),
      'shell'             => new sfWidgetFormInputText(),
      'user_machine_list' => new sfWidgetFormPropelChoice(array('multiple' => true, 'model' => 'Machine')),
      'user_group_list'   => new sfWidgetFormPropelChoice(array('multiple' => true, 'model' => 'UnixGroup')),
    ));

    $this->setValidators(array(
      'id'                => new sfValidatorChoice(array('choices' => array($this->getObject()->getId()), 'empty_value' => $this->getObject()->getId(), 'required' => false)),
      'name'              => new sfValidatorString(array('max_length' => 45, 'required' => false)),
      'uid'               => new sfValidatorInteger(array('min' => -2147483648, 'max' => 2147483647, 'required' => false)),
      'homedir'           => new sfValidatorString(array('max_length' => 255, 'required' => false)),
      'shell'             => new sfValidatorString(array('max_length' => 255, 'required' => false)),
      'user_machine_list' => new sfValidatorPropelChoice(array('multiple' => true, 'model' => 'Machine', 'required' => false)),
      'user_group_list'   => new sfValidatorPropelChoice(array('multiple' => true, 'model' => 'UnixGroup', 'required' => false)),
    ));

    $this->widgetSchema->setNameFormat('unix_user[%s]');

    $this->errorSchema = new sfValidatorErrorSchema($this->validatorSchema);

    parent::setup();
  }

  public function getModelName()
  {
    return 'UnixUser';
  }


  public function updateDefaultsFromObject()
  {
    parent::updateDefaultsFromObject();

    if (isset($this->widgetSchema['user_machine_list']))
    {
      $values = array();
      foreach ($this->object->getUserMachines() as $obj)
      {
        $values[] = $obj->getMachineId();
      }

      $this->setDefault('user_machine_list', $values);
    }

    if (isset($this->widgetSchema['user_group_list']))
    {
      $values = array();
      foreach ($this->object->getUserGroups() as $obj)
      {
        $values[] = $obj->getUnixGroupId();
      }

      $this->setDefault('user_group_list', $values);
    }

  }

  protected function doSave($con = null)
  {
    parent::doSave($con);

    $this->saveUserMachineList($con);
    $this->saveUserGroupList($con);
  }

  public function saveUserMachineList($con = null)
  {
    if (!$this->isValid())
    {
      throw $this->getErrorSchema();
    }

    if (!isset($this->widgetSchema['user_machine_list']))
    {
      // somebody has unset this widget
      return;
    }

    if (null === $con)
    {
      $con = $this->getConnection();
    }

    $c = new Criteria();
    $c->add(UserMachinePeer::UNIX_USER_ID, $this->object->getPrimaryKey());
    UserMachinePeer::doDelete($c, $con);

    $values = $this->getValue('user_machine_list');
    if (is_array($values))
    {
      foreach ($values as $value)
      {
        $obj = new UserMachine();
        $obj->setUnixUserId($this->object->getPrimaryKey());
        $obj->setMachineId($value);
        $obj->save();
      }
    }
  }

  public function saveUserGroupList($con = null)
  {
    if (!$this->isValid())
    {
      throw $this->getErrorSchema();
    }

    if (!isset($this->widgetSchema['user_group_list']))
    {
      // somebody has unset this widget
      return;
    }

    if (null === $con)
    {
      $con = $this->getConnection();
    }

    $c = new Criteria();
    $c->add(UserGroupPeer::UNIX_USER_ID, $this->object->getPrimaryKey());
    UserGroupPeer::doDelete($c, $con);

    $values = $this->getValue('user_group_list');
    if (is_array($values))
    {
      foreach ($values as $value)
      {
        $obj = new UserGroup();
        $obj->setUnixUserId($this->object->getPrimaryKey());
        $obj->setUnixGroupId($value);
        $obj->save();
      }
    }
  }

}
